@@ -24,7 +24,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 __author__ = 'Paul Scott-Murphy, William McBrine'
 __maintainer__ = 'Jakub Stasiak <jakub@stasiak.at>'
-__version__ = '0.15'
+__version__ = '0.15.1'
 __license__ = 'LGPL'
 
 import time
@@ -880,7 +880,7 @@ class Listener(object):
             # If the socket was closed by another thread -- which happens
             # regularly on shutdown -- an EBADF exception is thrown here.
             # Ignore it.
-            if e[0] == socket.EBADF:
+            if e.errno == socket.EBADF:
                 return
             else:
                 raise e
